# 浮动路由

### 一、浮动路由概述

1. **浮动路由是什么**
   - 浮动路由又称为路由备份，由两条或多条链路组成浮动路由
   - 浮动路由指配置两条静态路由，这两条静态路由的目的地址相同，但是下一跳地址不同两条静态路由
   - 给这两条静态路由设置不同的优先级，优先级高的那条静态路由做为主链路，优先级低的那条静态路由做为备份链路
   - 当主链路出现故障的时候，备份链路进入路由表中，顶替主链路承担数据转发任务
   - 当主链路故障恢复的时候，主链路进入路由表，承担数据转发任务，备份链路变为不可用状态移出路由表
2. **浮动路由的作用**
   - 预防单路径故障，保持网络的不中断
3. **浮动路由特点**
   - 浮动路由在同一时刻，数据只会由一条路径进行转发

### 二、路由的优先级

1. 当去往同一个目的地有多条路由时，为了判断最优路由，各路由协议（包括静态路由）都被赋予了一个优先级

2. 优先级高的（数值小）的路由会成为最优路由，路由器会将最优路由条目放入本地IP核心路由表中

3. 路由优先级：优先级用数值表示，数值越小优先级越高

   - Direct： 直连路由	0

   - Static： 静态路由	60

   > 配置完浮动路由后，只有主链路那条路由会出现在路由表中，备份链路那条路由不会出现在路由表，当主链路故障时，备份链路那条路由才会进入路由表

### 三、浮动路由实验

![image-20240829193142450](https://picgo-noriu.oss-cn-beijing.aliyuncs.com/Images/image-20240829193142450.png)

- **需求**

  > 配置浮动路由，实现链路冗余（让192.168.2.0/24那条链路成为主链路）

- **配置步骤**

  - 第一步：配置PC的IP地址，掩码，网关
  - 第二步：交换机配置VLAN，接口加入指定的VLAN
    1. SW1交换机创建VLAN 10
    2. SW1交换机的所有接口都设置为Access模式，并加入指定的VLAN 10
    3. SW2交换机创建VLAN 40
    4. SW2交换机的所有接口都设置为Access模式，并加入指定的VLAN 40
  - 第三步：路由器配置接口IP地址
  - 第四步：路由器配置浮动路由
    1. 配置一条静态路由为主链路，静态路由默认优先级为60
    2. 配置一条静态路由为备份链路，指定路由优先级为70
  - 第五步：验证与测试
    1. 验证是否主链路转发数据
    2. 验证是否主链路那条路由进入路由表
    3. 让主链路出现故障，验证备份链路是否起作用
    4. 配置命令

- **第一步：配置PC的IP地址，掩码，网关**

- **第二步：交换机配置VLAN，接口加入指定的VLAN**

  ```
  1. SW1交换机创建VLAN 10
  2. SW1交换机的所有接口都设置为Access模式，并加入指定的VLAN 10
  3. SW2交换机创建VLAN 40
  4. SW2交换机的所有接口都设置为Access模式，并加入指定的VLAN 40
  ```

  - **SW1配置**

    ```
    [SW1]vlan 10
    [SW1-vlan10]quit
    [SW1]port-group group-memb 
    [SW1]port-group group-member g0/0/1 to g0/0/3
    [SW1-port-group]port link-type access
    [SW1-port-group]port default vlan 10
    ```

  - **SW2配置**

    ```
    [SW2]vlan 40
    [SW2-vlan40]quit
    [SW2]port-group group-member g0/0/1 g0/0/2
    [SW2-port-group]port link-type access
    [SW2-port-group]port default vlan 40
    ```

- **第三步：路由器配置接口IP地址**

  - **R1配置**

    ```
    [R1]int g0/0/0
    [R1-GigabitEthernet0/0/0]ip address 192.168.1.254 24
    [R1-GigabitEthernet0/0/0]int g0/0/1
    [R1-GigabitEthernet0/0/1]ip address 192.168.2.1 24
    [R1-GigabitEthernet0/0/1]int g0/0/2
    [R1-GigabitEthernet0/0/2]ip address 192.168.3.1 24
    ```

  - **R2配置**

    ```
    [R2]int g0/0/0
    [R2-GigabitEthernet0/0/0]ip address 192.168.4.254 24
    [R2-GigabitEthernet0/0/0]int g0/0/1
    [R2-GigabitEthernet0/0/1]ip address 192.168.2.2 24
    [R2-GigabitEthernet0/0/1]int g0/0/2
    [R2-GigabitEthernet0/0/2]ip address 192.168.3.2 24
    ```

- **第四步：路由器配置浮动路由**

  ```
  1）配置一条静态路由为主链路，静态路由默认优先级为60
  2）配置一条静态路由为备份链路，指定路由优先级为70
  ```

  - **R1配置**

    ```
    [R1]ip route-static 192.168.4.0 24 192.168.2.2 //配置静态路由
    [R1]ip route-static 192.168.4.0 24 192.168.3.2 preference 70 //配置静态路由并指定优先级
    ```

  - **R2配置**

    ```
    [R2]ip route-static 192.168.1.0 24 192.168.2.1 //配置静态路由
    [R2]ip route-static 192.168.1.0 24 192.168.3.1 preference 70 //配置静态路由并指定优先级
    ```

- **第五步：验证与测试**

  1. 验证是否主链路转发数据
  2. 验证是否主链路那条路由进入路由表
  3. 主链路出现故障，验证备份链路是否起作用

  ```
  PC1>tracert 192.168.4.3 使用路由追踪或数据抓包验证
  [R1]display ip routing-table //查看进入路由表的最优路由
  [R1] display  ip routing-table  192.168.4.3
  [R1]display ip routing-table protocol static //查看静态路由
  Static routing table status : <Active>-活跃
  Destination/Mask Proto Pre  Cost NextHop Interface
  192.168.4.0/24 Static 60  0 192.168.2.2  G0/0/1
  Static routing table status : <Inactive>-不活跃的-停用的
  Destination/Mask Proto Pre Cost NextHop Interface
  192.168.4.0/24 Static 70  0 192.168.3.2  G0/0/2
  ```

  > shutdown 掉R1的g0/0/1 让主链路故障验证备份链路是否会进入路由表，承担数据转发任务

### 四、知识总结

1. 浮动路由： 路由备份
2. 浮动路由作用：预防单路径故障，实现路由备份，保障网络不中断
3. 浮动路由特点：同一时间只有一条链路转发数据，只有一条最优的路由进入IP核心路由表
   - 当主链路故障，备份链路承担流量转发任务
   - 当主链路恢复，备份链路被移出IP核心路由表
4. 配置浮动路由，选择最优路径，依靠是的路由优先级
5. 路由优先级的数值范围：0-255，　数值越小越优先
6. 直连路由的优先级默认是0
7. 静态路由的优先级默认是60



